/*
 * Copyright (c) 2005 CNRS/LAAS
 *
 * Permission to use, copy, modify, and distribute this software for any
 * purpose with or without fee is hereby granted, provided that the above
 * copyright notice and this permission notice appear in all copies.
 *
 * THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
 * WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
 * ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
 * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */
/* $LAAS$ */

#include <errno.h>
#include <fcntl.h>
#include <stdio.h>
#include <stdlib.h>
#include <unistd.h>

#include "contec_dio.h"
#include "jidogrip.h"

/*----------------------------------------------------------------------*/

GRIP_STR *
jidogripInit(char *deviceName)
{
	GRIP_STR *d;

	d = (GRIP_STR *)malloc(sizeof(GRIP_STR));
	if (d == NULL) 
		return NULL;
	d->fd = open(deviceName, O_RDWR);
	if (d->fd < 0) {
		free(d);
		return NULL;
	}
	return d;
}

/*----------------------------------------------------------------------*/

void
jidogripEnd(GRIP_STR *d)
{
	close(d->fd);
	free(d);
}

/*----------------------------------------------------------------------*/


unsigned int
jidogripStatus(GRIP_STR *d)
{
	DIO_ARG arg;

	arg.addr = GRIP_INPUT_REGISTER;
	if (ioctl(d->fd, CONTEC_DIO_READ, &arg) < 0) {
		fprintf(stderr, "%s: ioctl error %s\n", 
		       __func__, strerror(errno));
		return 0;
	}
	return (unsigned int)arg.value;
}

/*----------------------------------------------------------------------*/

int
jidogripClose(GRIP_STR *d)
{
	DIO_ARG arg;

	arg.addr = GRIP_OUTPUT_REGISTER;
	if (ioctl(d->fd, CONTEC_DIO_READ, &arg) < 0) {
		fprintf(stderr, "%s: ioctl error %s\n", 
		       __func__, strerror(errno));
		return -1;
	}
	arg.value |= GRIP_CLOSE_COMMAND;
	if (ioctl(d->fd, CONTEC_DIO_WRITE, &arg) < 0) {
		fprintf(stderr, "%s: ioctl error %s\n", 
		       __func__, strerror(errno));
		return -1;
	}
	return 0;
}

/*----------------------------------------------------------------------*/

int
jidogripOpen(GRIP_STR *d)
{
	DIO_ARG arg;

	arg.addr = GRIP_OUTPUT_REGISTER;
	if (ioctl(d->fd, CONTEC_DIO_READ, &arg) < 0) {
		fprintf(stderr, "%s: ioctl error %s\n", 
		       __func__, strerror(errno));
		return -1;
	}
	arg.value &= ~GRIP_CLOSE_COMMAND;
	if (ioctl(d->fd, CONTEC_DIO_WRITE, &arg) < 0) {
		fprintf(stderr, "%s: ioctl error %s\n", 
		       __func__, strerror(errno));
		return -1;
	}
	return 0;
}

/*----------------------------------------------------------------------*/

int
jidogripStop(GRIP_STR *d)
{
	DIO_ARG arg;

	arg.addr = GRIP_OUTPUT_REGISTER;
	if (ioctl(d->fd, CONTEC_DIO_READ, &arg) < 0) {
		fprintf(stderr, "%s: ioctl error %s\n", 
		       __func__, strerror(errno));
		return -1;
	}
	arg.value |= GRIP_STOP_COMMAND;
	if (ioctl(d->fd, CONTEC_DIO_WRITE, &arg) < 0) {
		fprintf(stderr, "%s: ioctl error %s\n", 
		       __func__, strerror(errno));
		return -1;
	}
	return 0;
}

/*----------------------------------------------------------------------*/

int
jidogripStart(GRIP_STR *d)
{
	DIO_ARG arg;

	arg.addr = GRIP_OUTPUT_REGISTER;
	if (ioctl(d->fd, CONTEC_DIO_READ, &arg) < 0) {
		fprintf(stderr, "%s: ioctl error %s\n", 
		       __func__, strerror(errno));
		return -1;
	}
	arg.value &= ~GRIP_STOP_COMMAND;
	if (ioctl(d->fd, CONTEC_DIO_WRITE, &arg) < 0) {
		fprintf(stderr, "%s: ioctl error %s\n", 
		       __func__, strerror(errno));
		return -1;
	}
	return 0;
}

/*----------------------------------------------------------------------*/


int
jidogripSlow(GRIP_STR *d)
{
	DIO_ARG arg;

	arg.addr = GRIP_OUTPUT_REGISTER;
	if (ioctl(d->fd, CONTEC_DIO_READ, &arg) < 0) {
		fprintf(stderr, "%s: ioctl error %s\n", 
		       __func__, strerror(errno));
		return -1;
	}
	arg.value |= GRIP_SLOW_COMMAND;
	if (ioctl(d->fd, CONTEC_DIO_WRITE, &arg) < 0) {
		fprintf(stderr, "%s: ioctl error %s\n", 
		       __func__, strerror(errno));
		return -1;
	}
	return 0;
}

/*----------------------------------------------------------------------*/

int
jidogripFast(GRIP_STR *d)
{
	DIO_ARG arg;

	arg.addr = GRIP_OUTPUT_REGISTER;
	if (ioctl(d->fd, CONTEC_DIO_READ, &arg) < 0) {
		fprintf(stderr, "%s: ioctl error %s\n", 
		       __func__, strerror(errno));
		return -1;
	}
	arg.value &= ~GRIP_SLOW_COMMAND;
	if (ioctl(d->fd, CONTEC_DIO_WRITE, &arg) < 0) {
		fprintf(stderr, "%s: ioctl error %s\n", 
		       __func__, strerror(errno));
		return -1;
	}
	return 0;
}

/*----------------------------------------------------------------------*/
