/*
 * Copyright (c) 2005 CNRS/LAAS
 *
 * Permission to use, copy, modify, and distribute this software for any
 * purpose with or without fee is hereby granted, provided that the above
 * copyright notice and this permission notice appear in all copies.
 *
 * THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
 * WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
 * ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
 * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */
/* $LAAS$ */

#include <errno.h>
#include <stdio.h>
#include "jidogrip.h"

GRIP_STR *grip = NULL;

static 
void parseCmd(int cmd)
{
	unsigned int status;

	switch (cmd) {
	case 0:
		printf("bye\n");
		jidogripEnd(grip);
		exit(0);
	case 1:
		printf("Open\n");
		jidogripOpen(grip);
		break;
	case 2:
		printf("Close\n");
		jidogripClose(grip);
		break;
	case 3:
		printf("Stop\n");
		jidogripStop(grip);
		break;
	case 4:
		printf("Start\n");
		jidogripStart(grip);
		break;
	case 5:
		printf("Slow\n");
		jidogripSlow(grip);
		break;
	case 6:
		printf("Fast\n");
		jidogripFast(grip);
		break;
	case 7:
		status = jidogripStatus(grip);
		printf("Status: 0x%02x: ", status);
		printf(status & GRIP_STOP_INPUT ?
		       "Stopped " : "Active ");
		printf(status & GRIP_OPEN_INPUT ?
		       "Open" : "");
		printf(status & GRIP_CLOSE_INPUT ?
		       "Closed" : "");
		putchar('\n');
		break;
	default:
		printf("Unknown command %d\n", cmd);
		break;
	}
}

int 
main(int argc, char *argv[])
{
	int cmd = 0;
	char buf[1024];

	if (argc == 2) {
		if (strcmp(argv[1], "open") == 0) 
			cmd = 1;
		else if (strcmp(argv[1], "close") == 0)
			cmd = 2;
		else if (strcmp(argv[1], "stop") == 0)
			cmd = 3;
		else if (strcmp(argv[1], "start") == 0)
			cmd = 4;
		else if (strcmp(argv[1], "slow") == 0)
			cmd = 5;
		else if (strcmp(argv[1], "fast") == 0)
			cmd = 6;
		else if (strcmp(argv[1], "status") == 0)
			cmd = 7;
		else {
			fprintf(stderr, 
				"usage: %s "
				"[open|close|stop|start|slow|fast|status]\n", 
				argv[0]);
			exit(1);
		}
	}
	grip = jidogripInit("/dev/contec_dio");
	if (grip == NULL) {
		fprintf(stderr, "gripOpen: %s\n", strerror(errno));
	}
	if (cmd != 0) {
		parseCmd(cmd);
		jidogripEnd(grip);
		exit(0);
	}

	while (1) {
		printf("\n");
		printf("0\tquit\n");
		printf("1\topen\n");
		printf("2\tclose\n");
		printf("3\tstop\n");
		printf("4\tstart\n");
		printf("5\tslow\n");
		printf("6\tfast\n");
		printf("7\tstatus\n");
		printf("\n> ");
		fflush(stdout);
		if (fgets(buf, sizeof(buf), stdin) == NULL) {
			printf("eof\n");
			jidogripEnd(grip);
			exit(2);
		}
		if (sscanf(buf, "%d", &cmd) != 1) {
			continue;
		}
		parseCmd(cmd);
	} /* while */
	return 0;
}

