/*
 * Copyright (c) 2005 CNRS/LAAS
 *
 * Permission to use, copy, modify, and distribute this software for any
 * purpose with or without fee is hereby granted, provided that the above
 * copyright notice and this permission notice appear in all copies.
 *
 * THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
 * WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
 * ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
 * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */
/* $LAAS$ */

/**
 ** Short test program reading data from the USB/Parallel converter 
 ** that transmits the values from the sensors on the grip 
 **/

#include <stdio.h>
#include <unistd.h>
#include <usb.h>
#include <ftdi.h>

void 
ftdi_fatal (struct ftdi_context *ftdi, char *str)
{
	fprintf (stderr, "%s: %s\n", 
		 str, ftdi_get_error_string (ftdi));
	exit (1); 
}



int 
main(int argc, char **argv)
{
	struct ftdi_context ftdic;
	int i, n;
	unsigned char data[10240];
	int delay = 100000; /* 100 thousand microseconds: 
			       1 tenth of a second */
	
	
	ftdi_init(&ftdic);
	
	if (ftdi_usb_open(&ftdic, 0x0403, 0x6001) < 0)
		ftdi_fatal (&ftdic, "Can't open ftdi device");
#if 0
	if (ftdi_enable_bitbang(&ftdic, 0xFF) < 0)
		ftdi_fatal (&ftdic, "Can't enable bitbang"); 
#endif
	
	while (1) {
		usleep(10000);
		n = ftdi_read_data(&ftdic, data, sizeof(data));
		if (n < 0) {
			ftdi_fatal(&ftdic, "Read data\n");
		}
		if (n == 0) {
#if 0
			printf("read_data returns 0\n");
#endif

		} else {
			printf("read %d chars: ", n);
			for (i = 0; i < 20; i++) {
			  /* putchar(data[i]); */
			  printf("0x%02x ", data[i]);
			}
			printf("...\n\n");
		}
	}
	exit (0);
}
